How-to Guides
=============

.. toctree::
   :maxdepth: 1
   :titlesonly:

   hardware_setup
   linux_cuda_setup
   working_with_cli

   .. data/how_to_load_custom_dataset

   data/how_to_use_private_data_source
   data/how_to_make_a_custom_dataset
   data/how_to_write_a_multistage_pipeline
   data/how_to_write_a_sample_processor
   
   training/implement_a_custom_model
   training/implement_a_custom_trainer
   training/use_callbacks
   
   .. data/how_to_write_data_preprocessors
   .. data/how_to_write_data_collators

   .. training/how_to_configure_all_training_options
   .. training/how_to_use_custom_model
   .. training/how_to_write_custom_loss_or_metric

   inference/how_to_run_evaluation_on_trained_models
   .. inference/how_to_run_inference_via_cli
   .. inference/how_to_run_inference_via_code
